unit Main;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls,
  Driver, paras;

   //The program can only support 255 devices in Device List.
   const MAX_ENTRIES = 255;
   //The program can only support 50 ports on every device.
   const MAX_PORTS   = 50;
   //Note: If any more devices or ports you want to support, please modify the
   //      number given above.
type
  TMainForm = class(TForm)
    Group_Device: TGroupBox;
    Label1: TLabel;
    CmbDevList: TComboBox;
    Label2: TLabel;
    Label3: TLabel;
    DOPorts: TEdit;
    DIPorts: TEdit;
    BtnOpenDev: TButton;
    Group_Read: TGroupBox;
    Label4: TLabel;
    Label5: TLabel;
    Label6: TLabel;
    BtnRead: TButton;
    DIPortStart: TEdit;
    DIData: TEdit;
    DIPortCnt: TEdit;
    Label7: TLabel;
    Group_Write: TGroupBox;
    Label8: TLabel;
    Label9: TLabel;
    Label10: TLabel;
    Label11: TLabel;
    DOPortStart: TEdit;
    DOData: TEdit;
    DOPortCnt: TEdit;
    BtnWrite: TButton;
    Group_State: TGroupBox;
    Label12: TLabel;
    Label13: TLabel;
    Label14: TLabel;
    Label15: TLabel;
    DOSPortStart: TEdit;
    DOSPortCnt: TEdit;
    DOSData: TEdit;
    BtnDOState: TButton;
    Label16: TLabel;
    Label18: TLabel;
    Label17: TLabel;

    procedure BtnOpenDevClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure BtnReadClick(Sender: TObject);
    procedure BtnWriteClick(Sender: TObject);
    procedure BtnDOStateClick(Sender: TObject);
    procedure FormDestroy(Sender: TObject);

  private
    { Private declarations }
    DevNumList       : array[0..MAX_ENTRIES] of Integer;
    DevHandle        : Integer;
    DIPortCount      : Longword;
    DOPortCount      : Longword;
    szErrMsg         : ShortString;
    DataBuffer       : array[0..MAX_PORTS] of BYTE;

  public
    { Public declarations }
    function InitialDeviceList() : Boolean;
    function CharToHex ( c : char ) : BYTE;
  end;

var
  MainForm: TMainForm;

implementation

{$R *.dfm}

{---------------------------------------------------}
function TMainForm.InitialDeviceList() : Boolean;
var
      lErrCde : LRESULT;
      DevCount : Smallint;
      outEntries : Smallint;
      DeviceList : array [0..MAX_ENTRIES] of PT_DEVLIST;
      i : Integer;
begin

   {Firstly, get the count of the device list}
   lErrCde := DRV_DeviceGetNumOfList( DevCount );
   if ( lErrCde <> SUCCESS ) then
   begin
      DRV_GetErrorMessage( lErrCde, @szErrMsg );
      begin
         Application.MessageBox( @szErrMsg, 'Driver Error', MB_OK or MB_ICONERROR);
      end;
      InitialDeviceList := false;
      Exit;
   end;
    if ( DevCount > MAX_ENTRIES ) then
    begin
      Application.MessageBox( 'Too many device to run the program!', 'Sorry', MB_OK or MB_ICONINFORMATION );
      InitialDeviceList := false;
      Exit;
    end;
    if ( DevCount = 0 ) then
    begin
      Application.MessageBox( 'There no device in the Device list!', 'Prompt', MB_OK or MB_ICONINFORMATION );
      InitialDeviceList := false;
      Exit;
    end;

   {Secondly, get device list}
   lErrCde := DRV_DeviceGetList( DeviceList[0], MAX_ENTRIES, outEntries );
   if ( lErrCde <> SUCCESS ) then
   begin
      DRV_GetErrorMessage( lErrCde, @szErrMsg );
      begin
         Application.MessageBox( @szErrMsg, 'Driver Error', MB_OK or MB_ICONERROR );
      end;
      InitialDeviceList := false;
      Exit;
   end;

   {Thirdly, fill the combobox and save the device num orderly}
   for i := 0 To (outEntries - 1) do
   begin
      CmbDevList.Items.Add( DeviceList[i].szDeviceName );
      DevNumList[i] := DeviceList[i].dwDeviceNum;
   end;
   CmbDevList.ItemIndex := 0;
   InitialDeviceList := true;
   
end;
{----------------------------------------------------}


{---------------------------------------------------}
procedure TMainForm.BtnOpenDevClick(Sender: TObject);
var
   nSel     : Integer;
   nDevNum  : Integer;
   lErrCde  : Longint;
   nDataLen : Integer;

begin
   {Firstly, Get the device number}
   nSel := CmbDevList.ItemIndex;
   if ( nSel < 0 ) then
   begin
      Application.MessageBox( 'Please select a device firstly', 'Prompt', MB_OK or MB_ICONINFORMATION );
      Exit;
   end;
   nDevNum := DevNumList[ nSel ];

   {Secondly, open the device}
   {--Firstly, close the device if the device has been opened}
   if ( DevHandle <> 0 ) then
   begin
      DRV_DeviceClose( DevHandle );
      DevHandle := 0;
   end;
   {--Secondly, open the device}
   lErrCde := DRV_DeviceOpen( nDevNum, DevHandle );
   if ( lErrCde <> SUCCESS ) then
   begin
      DRV_GetErrorMessage( lErrCde, @szErrMsg );
      Application.MessageBox( @szErrMsg, 'Driver Error', MB_OK or MB_ICONERROR );
      BtnDOState.Enabled := false;
      BtnRead.Enabled := false;
      BtnWrite.Enabled := false;
      DOPorts.Text := '';
      DIPorts.Text := '';
      DIPortCount := 0;
      DOPortCount := 0;
      Exit;
   end;

   {Thirdly, find DIO port count and fill the edit}
   {--DI port count}
   nDataLen := Sizeof( Integer );
   lErrCde := DRV_DeviceGetProperty( DevHandle, CFG_DiPortCount, @DIPortCount, nDataLen );
   if ( lErrCde = SUCCESS ) then
   begin
      DIPorts.Text := IntToStr( DIPortCount );
      if ( DIPortCount > 0 ) then
      begin
         BtnRead.Enabled := true
      end
      else
      begin
         BtnRead.Enabled := false;
         DIPorts.Text := '';
         DIPortCount := 0;
      end;
   end
   else
   begin
      BtnRead.Enabled := false;
      DIPorts.Text := '';
      DIPortCount := 0;
   end;
   {--DO port count}
   nDataLen := Sizeof( Integer );
   lErrCde := DRV_DeviceGetProperty( DevHandle, CFG_DoPortCount, @DOPortCount, nDataLen );
   if ( lErrCde = SUCCESS ) then
   begin
      DOPorts.Text := IntToStr( DOPortCount );
      if ( DOPortCount > 0 ) then
      begin
         BtnWrite.Enabled := true;
         BtnDOState.Enabled := true
      end
      else
      begin
         BtnWrite.Enabled := false;
         BtnDOState.Enabled := false;
         DOPorts.Text := '';
         DOPortCount := 0;
      end;
   end
   else
   begin
      BtnWrite.Enabled := false;
      BtnDOState.Enabled := false;
      DOPorts.Text := '';
      DOPortCount := 0;
   end;


end;
{---------------------------------------------------}
procedure TMainForm.FormCreate(Sender: TObject);
begin
   {Initial variables necessariely}
   DevHandle := 0;
   DIPortCount := 0;
   DOPortCount := 0;
   {Initial Device list}
   if ( InitialDeviceList() = false ) then
   begin
      Application.MessageBox( 'Can not find devices','Error',MB_OK or MB_ICONERROR );
      Exit;
   end;
end;
{----------------------------------------------------}

procedure TMainForm.BtnReadClick(Sender: TObject);
var
   nPortStart : Longword;
   nPortCount : Longword;
   lErrCde    : Longint;
   i,j        : Integer;
   str        : string;
   strTemp    : ShortString;

begin

   if ( DevHandle = 0 ) then
   begin
      Application.MessageBox('Please open a device firstly!', 'Prompt', MB_OK or MB_ICONINFORMATION );
      Exit;
   end;

   {Firstly, get start port number}
   strTemp := DIPortStart.Text;
   if ( Length(strTemp) = 0 ) then
   begin
      Application.MessageBox('Please input an appropriate number firstly!', 'Prompt', MB_OK or MB_ICONINFORMATION );
      Exit;
   end;
   try
      nPortStart := StrToInt( strTemp );
   except
      on EConvertError do
      begin
      Application.MessageBox('Please input an appropriate number !', 'Prompt', MB_OK or MB_ICONINFORMATION );
      Exit;
      end;
   end;

   if ( nPortStart >= DIPortCount ) then
   begin
      Application.MessageBox('Start port is not avaliable, please input again!', 'Prompt', MB_OK or MB_ICONINFORMATION );
      Exit;
   end;

   {Secondly, get port count}
   strTemp := DIPortCnt.Text;
   if ( Length(strTemp) = 0 ) then
   begin
      Application.MessageBox('Please input an appropriate number firstly!', 'Prompt', MB_OK or MB_ICONINFORMATION );
      Exit;
   end;
   try
      nPortCount := StrToInt( strTemp );
   except
      on EConvertError do
      begin
      Application.MessageBox('Please input an appropriate number !', 'Prompt', MB_OK or MB_ICONINFORMATION );
      Exit;
      end;
   end;
   if ( ( ( nPortStart + nPortCount ) > DIPortCount ) OR ( nPortCount = 0 ) ) then
   begin
      Application.MessageBox('Port count is not avaliable, please input again!', 'Prompt', MB_OK or MB_ICONINFORMATION );
      Exit;
   end;

   {Thirdly, allocate memory for DI data
    pDataBuf := AllocMem ( nPortCount );
    if ( pDataBuf = nil ) then
    begin
      Application.MessageBox('No enough memory to allocate!', 'System Error', MB_OK or MB_ICONERROR );
      Exit;
    end;}

   {Fourthly, read data from the ports}
   lErrCde := AdxDioReadDiPorts( DevHandle, nPortStart, nPortCount, DataBuffer[0] );
   if ( lErrCde <> SUCCESS ) then
   begin
      DRV_GetErrorMessage( lErrCde, @szErrMsg );
      Application.MessageBox( @szErrMsg, 'Driver Error', MB_OK or MB_ICONERROR );
      Exit
   end
   else
   begin
      for i := 0 To (nPortCount - 1)  do
      begin
         str := str + IntToHex( DataBuffer[i], 2 ) + ' ';
      end;
      DIData.Text := str;
   end;

end;
{-----------------------------------------------------------------------}
function TMainForm.CharToHex ( c : char ) : BYTE;
var
   str   : string;
begin
   if ( ( c >= '0' ) AND ( c <= '9' ) ) then
   begin
      Result := BYTE(c) - BYTE('0');
      Exit;
   end;

   str := LowerCase( c );
   c := str[1];
   if ( ( c >= 'a' ) AND ( c <= 'f' ) ) then
   begin
      Result := BYTE(c) - BYTE('a') + $0a;
      Exit;
   end;
   Result := 0;
end;
{-----------------------------------------------------------------------}
procedure TMainForm.BtnWriteClick(Sender: TObject);
var
   nPortStart             : Longword;
   nPortCount             : Longword;
   lErrCde                : Longint;
   i                      : Longword;
   j                      : Longword;
   k, nDataCnt            : Longword;
   str                    : string;
   strTemp                : ShortString;
   nTextLen               : Longword;
   High, Low              : BYTE;
begin

   if ( DevHandle = 0 ) then
   begin
      Application.MessageBox('Please open a device firstly!', 'Prompt', MB_OK or MB_ICONINFORMATION );
      Exit;
   end;

   {Firstly, get start port number}
   strTemp := DOPortStart.Text;
   if ( Length(strTemp) = 0 ) then
   begin
      Application.MessageBox('Please input an appropriate number !', 'Prompt', MB_OK or MB_ICONINFORMATION );
      Exit;
   end;
   try
      nPortStart := StrToInt( strTemp );
   except
      on EConvertError do
      begin
      Application.MessageBox('Please input an appropriate number !', 'Prompt', MB_OK or MB_ICONINFORMATION );
      Exit;
      end;
   end;
   if ( nPortStart >= DOPortCount ) then
   begin
      Application.MessageBox('Start port is not avaliable, please input again!', 'Prompt', MB_OK or MB_ICONINFORMATION );
      Exit;
   end;

   {Secondly, get port count}
   strTemp := DOPortCnt.Text;
   if ( Length(strTemp) = 0 ) then
   begin
      Application.MessageBox('Please input an appropriate number !', 'Prompt', MB_OK or MB_ICONINFORMATION );
      Exit;
   end;
   try
      nPortCount := StrToInt( strTemp );
   except
      on EConvertError do
      begin
      Application.MessageBox('Please input an appropriate number !', 'Prompt', MB_OK or MB_ICONINFORMATION );
      Exit;
      end;
   end;
   if ( ( ( nPortStart + nPortCount ) > DOPortCount ) OR ( nPortCount = 0 ) ) then
   begin
      Application.MessageBox('Port count is not avaliable, please input again!', 'Prompt', MB_OK or MB_ICONINFORMATION );
      Exit;
   end;

   {Thirdly, allocate memory for DI data
    pDataBuf := AllocMem ( nPortCount );
    if ( pDataBuf = nil ) then
    begin
      Application.MessageBox('No enough memory to allocate!', 'System Error', MB_OK or MB_ICONERROR );
      Exit;
    end;}

   {Fourthly, Get data that user input and convert them to BYTE data}
   {          Note: two characters indicates one number}
   str := DOData.Text;
   nTextLen := Length( str );
   if ( nTextLen = 0 ) then
   begin
      Application.MessageBox('Please input a data firstly!', 'Prompt', MB_OK or MB_ICONINFORMATION );
      Exit;
   end;
   nDataCnt := nTextLen div 2;

   i := 1;
   j := 0;
   k := 0;  {Character index}

   While (j < nPortCount) do
   begin
      If ( j <= nDataCnt ) Then
      begin
        { 16 means move the number for four bits left to be high data. 16 = 2^4}
        High := CharToHex(str[i]) * 16;
        k := k + 1;
        If ( (j = nDataCnt) And (nTextLen = k) ) Then {The last charater in the string}
        begin
            Low := 0;
        end
        Else
        begin
            Low := CharToHex(str[i + 1]);
            k := k + 1;
        End;
        DataBuffer[j] := High or Low;
        i := i + 2;
      End
      Else
      begin
        DataBuffer[j] := 0 ;
      End;
      j := j + 1;
   end;

   {Fifthly, write data to the ports}
   lErrCde := AdxDioWriteDoPorts( DevHandle, nPortStart, nPortCount, DataBuffer[0] );
   if ( lErrCde <> SUCCESS ) then
   begin
      DRV_GetErrorMessage( lErrCde, @szErrMsg );
      Application.MessageBox( @szErrMsg, 'Driver Error', MB_OK or MB_ICONERROR );
      Exit
   end;

end;
{-----------------------------------------------------------------------}
procedure TMainForm.BtnDOStateClick(Sender: TObject);
var
   nPortStart : Integer;
   nPortCount : Integer;
   lErrCde    : Longint;
   i,j        : Integer;
   str        : string;
   strTemp    : ShortString;

begin

   if ( DevHandle = 0 ) then
   begin
      Application.MessageBox('Please open a device firstly!', 'Prompt', MB_OK or MB_ICONINFORMATION );
      Exit;
   end;

   {Firstly, get start port number}
   strTemp := DOSPortStart.Text;
   if ( Length(strTemp) = 0 ) then
   begin
      Application.MessageBox('Please input an appropriate number firstly!', 'Prompt', MB_OK or MB_ICONINFORMATION );
      Exit;
   end;
   try
      nPortStart := StrToInt( strTemp );
   except
      on EConvertError do
      begin
      Application.MessageBox('Please input an appropriate number !', 'Prompt', MB_OK or MB_ICONINFORMATION );
      Exit;
      end;
   end;

   if ( nPortStart >= DOPortCount ) then
   begin
      Application.MessageBox('Start port is not avaliable, please input again!', 'Prompt', MB_OK or MB_ICONINFORMATION );
      Exit;
   end;

   {Secondly, get port count}
   strTemp := DOSPortCnt.Text;
   if ( Length(strTemp) = 0 ) then
   begin
      Application.MessageBox('Please input an appropriate number firstly!', 'Prompt', MB_OK or MB_ICONINFORMATION );
      Exit;
   end;
   try
      nPortCount := StrToInt( strTemp );
   except
      on EConvertError do
      begin
      Application.MessageBox('Please input an appropriate number !', 'Prompt', MB_OK or MB_ICONINFORMATION );
      Exit;
      end;
   end;
   if ( ( ( nPortStart + nPortCount ) > DOPortCount ) OR ( nPortCount = 0 ) ) then
   begin
      Application.MessageBox('Port count is not avaliable, please input again!', 'Prompt', MB_OK or MB_ICONINFORMATION );
      Exit;
   end;

   {Thirdly, allocate memory for DI data
    pDataBuf := AllocMem ( nPortCount );
    if ( pDataBuf = nil ) then
    begin
      Application.MessageBox('No enough memory to allocate!', 'System Error', MB_OK or MB_ICONERROR );
      Exit;
    end;}

   {Fourthly, read data from the ports}
   lErrCde := AdxDioGetCurrentDoPortsState( DevHandle, nPortStart, nPortCount, DataBuffer[0] );
   if ( lErrCde <> SUCCESS ) then
   begin
      DRV_GetErrorMessage( lErrCde, @szErrMsg );
      Application.MessageBox( @szErrMsg, 'Driver Error', MB_OK or MB_ICONERROR );
      Exit
   end
   else
   begin
      for i := 0 To (nPortCount - 1) do
      begin
         str := str + IntToHex( DataBuffer[i], 2 ) + ' ';
      end;
      DOSData.Text := str;
   end;
end;

{-----------------------------------------------------------------------}
procedure TMainForm.FormDestroy(Sender: TObject);
begin
   if ( DevHandle <> 0 ) then
   begin
      DRV_DeviceClose( DevHandle );
   end;

end;
{-----------------------------------------------------------------------}

end.
