//#############################################################################
//*****************************************************************************
//
//			Copyright (c) 2004 Xi'an R&D Center Advantech Automation Corp.
//
//     This is An Unpublished Work Containing Confidential  And Proprietary
//        Information Which Is The Property Of Advantech  Automation Corp.
//
//    Any Disclosure, Use, Or Reproduction, Without Written Authorization From
//              Advantech Automation Corp., Is Strictly Prohibit.
//
//*****************************************************************************
//#############################################################################
//
//	  File Name :  DIO_SOFT_DWORD.C
//	  Revision  :  1.0
//
//	  Created   :  08/26/2004
//
//   Description :
//     This examples performs the DIO Word and DWord operation.
//
//-----------------------------------------------------------------------------
// 
//   FUNCTIONS:
// 
//   InitApplication() - Initializes window data and registers window class
// 
//   InitInstance() - Saves instance handle and creates main window
// 
//   MainWndProc() - Process main window messages
// 
//   ConfigDlgProc() - Process the dialog box messages for configuration
//   
//   RunDlgProc() - Precess the dialog box message for run.
//
//-----------------------------------------------------------------------------


#include <windows.h>              /* required for all Windows applications */
#include <stdlib.h>
#include <dos.h>
#include <math.h>
#include <stdio.h>
#include <string.h>
#include "..\..\..\include\driver.h"
#include "resource.h"

// ------------------------------------------------------------------------
// CONSTANT DEFINITION
// ------------------------------------------------------------------------
#define     MAX_DEVICES     100

// ------------------------------------------------------------------------
// GLOBAL VARIABLES
// ------------------------------------------------------------------------
HANDLE      hInst;                    // current instance
HWND        hMainWnd;                 // main window handle

static      PT_DioReadPortWord      ptDioReadPortWord;     //DioReadPortWord table
static      PT_DioWritePortWord     ptDioWritePortWord;    //DioWritePortWord table
static      PT_DioReadPortDword     ptDioReadPortDword;    //DioReadPortDword table
static      PT_DioWritePortDword    ptDioWritePortDword;   //DioWritePortDword table
static		PT_DioGetCurrentDOWord	ptDioGetCurrentDOWord; //DioGetCurrentDOWord table
static		PT_DioGetCurrentDODword ptDioGetCurrentDODword;//DioGetCurrentDODword table

static      PT_DeviceGetFeatures    ptDevFeatures;  // Devfeatures table
static      DEVFEATURES             DevFeatures;

char        szErrMsg[80];             // used for MESSAGEBOX function
LRESULT     ErrCde;                   // return error code

DEVLIST     DeviceList[MAX_DEVICES];
DEVLIST     SubDeviceList[MAX_DEVICES];

LONG        DriverHandle = (LONG)NULL;          // driver handle
USHORT      gwPort = 0x0;								// device index

USHORT      gwDiValue = 0;								// read port Word  value
ULONG       glDiValue = 0;								// read port DWord value
USHORT		gwValidMask = 0;							// read port Word  valid mask
ULONG			glValidMask = 0;							// read port DWord valid mask
ULONG       glDoState = 0xA55A5AA5;             // write port data
USHORT		gwWriteMask = 0xFFFF;					// write port Word  mask
ULONG			glWriteMask = 0xFFFFFFFF;				// write port DWord mask
USHORT		gwGetDOValue = 0;
ULONG			glGetDOValue = 0;

USHORT      gwDevice = 0, gwSubDevice = 0;  // device index
SHORT       gnNumOfDevices, gnNumOfSubdevices;  // number of installed devices

USHORT      usTemp;

FARPROC     lpfnConfigDlgProc;        // config. dialog procedure
FARPROC     lpfnRunDlgProc;           // run dialog procedure

// ------------------------------------------------------------------------
// FUNCTION DECLARATION
// ------------------------------------------------------------------------
BOOL InitApplication(HANDLE hInstance);
BOOL InitInstance(HANDLE hInstance, int nCmdShow);
long FTYPE MainWndProc(
   HWND, 
   UINT, 
   WPARAM, 
   LPARAM);
int PASCAL WinMain(
   HINSTANCE hInstance,
	HINSTANCE hPrevInstance,
   LPSTR lpCmdLine,
	int nCmdShow);

void EditLimitHexCharacter(HWND hDlg, WPARAM wParam);

//*****************************************************************************
//    FUNCTION: WinMain(HANDLE, HANDLE, LPSTR, int)
//
//    PURPOSE: calls initialization function, processes message loop
//-----------------------------------------------------------------------------

int PASCAL WinMain(
   HINSTANCE   hInstance,                  // current instance
   HINSTANCE   hPrevInstance,              // previous instance
   LPSTR    lpCmdLine,                  // command line
   int      nCmdShow )                  // show-window type (open/icon)
{
   MSG msg;                                // message

   if (!hPrevInstance)
   {
      if (!InitApplication(hInstance))    // Initialize shared things
            return (FALSE);                 // Exits if unable to initialize
   }
        
   // Perform initializations that apply to a specific instance
   if (!InitInstance(hInstance, nCmdShow))
   {
      return (FALSE);
   }
        
   // Acquire and dispatch messages until a WM_QUIT message is received.
   while (GetMessage( 
             &msg,                    // message structure
             (HWND)NULL,              // handle of window receiving the message
				 (UINT)NULL,              // lowest message to examine             
				 (UINT)NULL ) )           // highest message to examine            
   {
      TranslateMessage(&msg);  // Translates virtual key codes
      DispatchMessage(&msg);   // Dispatches message to window
   }
   return ( msg.wParam );         // Returns the value from PostQuitMessage
}

//*****************************************************************************
//   FUNCTION: InitApplication(HANDLE)
//
//   PURPOSE: Initializes window data and registers window class
//-----------------------------------------------------------------------------
BOOL InitApplication(HANDLE hInstance )  // current instance
{
   WNDCLASS  wc;

   // Fill in window class structure with parameters that describe the
   // main window.
   wc.style = CS_HREDRAW | CS_VREDRAW; // Class style(s).
   wc.lpfnWndProc = (WNDPROC)MainWndProc;  // window process procedure
   wc.cbClsExtra = 0;                  // No per-class extra data.
   wc.cbWndExtra = 0;                  // No per-window extra data.
   wc.hInstance = hInstance;           // Application that owns the class.
   wc.hIcon = LoadIcon(hInstance, "IDI_ICON1");
   wc.hCursor = LoadCursor(NULL, IDC_ARROW);
   wc.hbrBackground = GetStockObject(WHITE_BRUSH);
   wc.lpszMenuName =  "MyMenu";   // Name of menu resource in .RC file.
   wc.lpszClassName = "MyClass";  // Name used in call to CreateWindow.

   // Register the window class and return success/failure code.
   return (RegisterClass(&wc));

}

//*****************************************************************************
//    FUNCTION:  InitInstance(HANDLE, int)
//
//    PURPOSE:  Saves instance handle and creates main window
//-----------------------------------------------------------------------------
BOOL InitInstance(
   HANDLE          hInstance,          // Current instance identifier.
   int             nCmdShow )           // Param for first ShowWindow() call.
{
   // Save the instance handle in static variable, which will be used in
   // many subsequence calls from this application to Windows.
   hInst = hInstance;

   // Create a main window for this application instance.
   hMainWnd = CreateWindow(
      "MyClass",                  // See RegisterClass() call.
      "Advantech Driver Demo : DIO_SOFT_DWORD" ,    // Window title bar
      WS_OVERLAPPEDWINDOW,        // Window style.
      CW_USEDEFAULT,              // Default horizontal position.
      CW_USEDEFAULT,              // Default vertical position.
      CW_USEDEFAULT,              // Default width.
      CW_USEDEFAULT,              // Default height.
      NULL,                       // Overlapped windows have no parent.
      NULL,                       // Use the window class menu.
      hInstance,                  // This instance owns this window.
      NULL );                     // Pointer not needed.
        

   // If window could not be created, return "failure"
   if (!hMainWnd)
   {
      return (FALSE);
   }
      

   // Make the window visible; update its client area; and return "success"

   ShowWindow(hMainWnd, nCmdShow);     // Show the window
   UpdateWindow(hMainWnd);             // Sends WM_PAINT message
   return (TRUE);              // Returns the value from PostQuitMessage
}

//*****************************************************************************
//    FUNCTION: ConfigDlgProc(HWND, unsigned, WPARAM, LPARAM)
//
//    PURPOSE:  Processes dialog box messages for configuration
//-----------------------------------------------------------------------------
BOOL  FTYPE ConfigDlgProc(
   HWND        hDlg,                          // window handle
   unsigned    message,                       // type of message
   WPARAM      wParam,                        // additional information
   LPARAM      lParam)                        // additional information
{
   char        szBuffer[40];
   int         nOutEntries;
	int         i;
	DWORD       dwIndex;

   switch (message)
   {
   case WM_INITDIALOG :
      {
         // --------------------------------
         // Initialize Device List Combobox
         // --------------------------------
         // get number of the installed devices
         ErrCde = DRV_DeviceGetNumOfList((SHORT far *)&gnNumOfDevices);
         if (ErrCde != SUCCESS)
         {
            DRV_GetErrorMessage(ErrCde,(LPSTR)szErrMsg);
            MessageBox(hMainWnd,(LPCSTR)szErrMsg, "Driver Message", MB_OK);
            return TRUE;
         }

         if (gnNumOfDevices > MAX_DEVICES)
         {
            gnNumOfDevices = MAX_DEVICES;
         }
            
         // retrieve the information of all installed devices
         ErrCde = DRV_DeviceGetList(
            (DEVLIST far *)&DeviceList[0],
            (SHORT)gnNumOfDevices, 
            (SHORT far *)&nOutEntries);
         if (ErrCde != (LONG)SUCCESS)
         {
            DRV_GetErrorMessage(ErrCde,(LPSTR)szErrMsg);
            MessageBox(hMainWnd,(LPCSTR)szErrMsg,"Driver Message",MB_OK);
            return TRUE;
         }

        // initialize the Device List Combobox with the retrieved information

        for (i = 0; i < gnNumOfDevices; i ++)
        {
           SendDlgItemMessage(
              hDlg, 
              IDC_DEVICE, 
              CB_ADDSTRING, 
              0,
              (LPARAM)((LPSTR)DeviceList[i].szDeviceName));
        }
            
        SendDlgItemMessage(
           hDlg, 
           IDC_DEVICE, 
           CB_SETCURSEL,
           (WPARAM)gwDevice,
           (LPARAM)0);


        // -----------------------------------------------------------
        // Initialize Module List Combobox for COM port or CAN devices
        // -----------------------------------------------------------

        // check if there is any device attached on this COM port or CAN

         gnNumOfSubdevices = DeviceList[gwDevice].nNumOfSubdevices;
         if (gnNumOfSubdevices > MAX_DEVICES)
         {
            gnNumOfSubdevices = MAX_DEVICES;
         }
            

         // retrieve the information of all installed devices
         if (gnNumOfSubdevices != 0)
         {
            ErrCde = DRV_DeviceGetSubList(
               (DWORD)DeviceList[gwDevice].dwDeviceNum,
               (DEVLIST far *)&SubDeviceList[0],
               (SHORT)gnNumOfSubdevices,
               (SHORT far *)&nOutEntries);
            if (ErrCde != (LONG)SUCCESS)
            {
               DRV_GetErrorMessage(ErrCde,(LPSTR)szErrMsg);
               MessageBox(
                  hMainWnd,
                  (LPCSTR)szErrMsg,
                  "Driver Message",
                  MB_OK);
               return TRUE;
            }


            // initialize the Module List Combobox with the retrieved
            // information

            EnableWindow(GetDlgItem(hDlg, IDC_MODULE), TRUE);
            SendDlgItemMessage(
               hDlg, 
               IDC_MODULE, 
               CB_RESETCONTENT, 
               0,
               (LPARAM)((LPSTR)0));

            for (i = 0; i < gnNumOfSubdevices; i++)
            {
               SendDlgItemMessage(
                  hDlg, 
                  IDC_MODULE, 
                  CB_ADDSTRING, 
                  0,
                  (LPARAM)((LPSTR)SubDeviceList[i].szDeviceName));
            }
                
            SendDlgItemMessage(
               hDlg, 
               IDC_MODULE, 
               CB_SETCURSEL,
				   (WPARAM)gwSubDevice, 
               (LPARAM)0);
         }
         else
         {
            EnableWindow(GetDlgItem(hDlg, IDC_MODULE), FALSE);
            SendDlgItemMessage(
               hDlg, 
               IDC_MODULE, 
               CB_RESETCONTENT, 
               0,
               (LPARAM)((LPSTR)0));
         }
         // -----------------------------
         // Initialize Output Channel
         // -----------------------------
		   sprintf( szBuffer, "%d", gwPort);
         SendDlgItemMessage(
            hDlg, 
            IDC_PORT, 
            EM_REPLACESEL, 
            0,
            (LPARAM)((LPSTR)szBuffer));
         return TRUE;
      }       
   case WM_COMMAND :
        switch (LOWORD(wParam))
        {
        case IDOK :
           {
               // get device selection
               dwIndex = SendDlgItemMessage(
                  hDlg, 
                  IDC_DEVICE,
				      CB_GETCURSEL, 
                  0, 
                  0);
			      if (dwIndex != CB_ERR)                   
               {
                     gwDevice = (WORD)dwIndex;
               }

			      // get sub-device selection
               dwIndex = SendDlgItemMessage(
                  hDlg, 
                  IDC_MODULE,
				      CB_GETCURSEL, 
                  0, 
                  0);
			      if (dwIndex != CB_ERR)
               {
                  gwSubDevice = (WORD)dwIndex;
               }
                   
               // Get channel number
               if ( SendDlgItemMessage(
                  hDlg, 
                  IDC_PORT,
				      EM_GETMODIFY, 
                  0, 
                  0))
               {
                  SendDlgItemMessage(
                     hDlg, 
                     IDC_PORT,
					      WM_GETTEXT,
							10,
							( LPARAM )( LPSTR )szBuffer ) ;
						gwPort = atoi( szBuffer );
               }
			   
               EndDialog(hDlg, 0);
               return TRUE;
           }			   
         case IDCANCEL :
            {
               EndDialog(hDlg, 0);
               return TRUE;
            }
                
		   case IDC_DEVICE:
            {
               // When device selection is changed, it needs to
			      // re-initialize sub-device combobox and input range
			      // combobox.		   
			      if (HIWORD(wParam) == CBN_SELCHANGE)
			      {
				      dwIndex = SendDlgItemMessage(
                     hDlg, 
                     IDC_DEVICE,
					      CB_GETCURSEL, 
                     0, 
                     0);
                  if (dwIndex != CB_ERR)
                  {
                     gwDevice = (WORD)dwIndex;
                  }
				      else
                  { 
                     return TRUE;
                  }
				      // ------------------------------------------------------
				      // Initialize Module Combobox for COM port or CAN devices
				      // ------------------------------------------------------
				      // check any device attached on this COM port or CAN   
				      gnNumOfSubdevices = DeviceList[gwDevice].nNumOfSubdevices;
				      if (gnNumOfSubdevices > MAX_DEVICES)
                  {
                     gnNumOfSubdevices = MAX_DEVICES;
                  }

				      // retrieve the information of all installed devices
				      if (gnNumOfSubdevices != 0)
				      {
					      ErrCde = DRV_DeviceGetSubList(
						      (DWORD)DeviceList[gwDevice].dwDeviceNum,
						      (DEVLIST far *)&SubDeviceList[0],
						      (SHORT)gnNumOfSubdevices,
						      (SHORT far *)&nOutEntries);
                     if (ErrCde != (LONG)SUCCESS)
					      {
						      DRV_GetErrorMessage(ErrCde,(LPSTR)szErrMsg);
						      MessageBox(
                           hMainWnd, 
                           (LPCSTR)szErrMsg,
							      "Driver Message", 
                           MB_OK);
						      return TRUE;
					      }
   
					      // initialize the Module List Combobox with the
					      // retrieved information
					      EnableWindow(GetDlgItem(hDlg, IDC_MODULE), TRUE);
					      SendDlgItemMessage(
                        hDlg, 
                        IDC_MODULE, 
                        CB_RESETCONTENT,
						      0, 
                        (LPARAM)((LPSTR)0));
					   
					      for (i = 0; i < gnNumOfSubdevices; i++)
                     {
                        SendDlgItemMessage(
                           hDlg, 
                           IDC_MODULE, 
                           CB_ADDSTRING, 
                           0,
						         (LPARAM)((LPSTR)SubDeviceList[i].szDeviceName));
                     }
						   
					      gwSubDevice = 0;
					   
					      SendDlgItemMessage(
                        hDlg, 
                        IDC_MODULE, 
                        CB_SETCURSEL,
						      (WPARAM)gwSubDevice, 
                        (LPARAM)0);
				      }
				      else
				      {
					      EnableWindow(GetDlgItem(hDlg, IDC_MODULE), FALSE);
					      SendDlgItemMessage(
                        hDlg, 
                        IDC_MODULE, 
                        CB_RESETCONTENT,
						      0, 
                        (LPARAM)((LPSTR)0));
				      }
			      }
			      return TRUE;
            }   
        }
        break;
    }
    return FALSE ;
}

//*****************************************************************************
//    FUNCTION: RunDlgProc(HWND, unsigned, WPARAM, LPARAM)
//
//    PURPOSE:  Processes dialog box messages for IDD_RUN
//-----------------------------------------------------------------------------
BOOL FTYPE RunDlgProc(
   HWND        hDlg,                          // window handle
   unsigned    message,                       // type of message
   WPARAM      wParam,                        // additional information
   LPARAM      lParam )                        // additional information
{
   char        szBuffer[40];
	char		   *pchar;
   int i;
   USHORT usPorts;

   switch (message)
   {
   case WM_INITDIALOG :
		{
         // Initialize Output Byte Value Check Button
         for (i = 0; i < 32; i++)
         {
            CheckDlgButton( hDlg, (IDC_D0 + i), ( glDoState & (0x1<<i)) );
         }
         
			// show write Word mask.
			//_ltoa( gwWriteMask, szBuffer, 16 );
         sprintf(szBuffer,"%X",gwWriteMask);
			SendDlgItemMessage( 
            hDlg,
				IDC_WRITEWORDMASK,
				WM_SETTEXT,
				0,
				( LPARAM )( ( LPSTR )szBuffer ) );
			// show write DWord mask.
			//_ltoa( glWriteMask, szBuffer, 16 );
         sprintf(szBuffer,"%X",glWriteMask);
			SendDlgItemMessage( 
            hDlg,
				IDC_WRITEDWORDMASK,
				WM_SETTEXT,
				0,
				( LPARAM )( ( LPSTR )szBuffer ) );

         //
         // open device
         if (gnNumOfSubdevices == 0)
			{
            ErrCde = DRV_DeviceOpen(
			               DeviceList[gwDevice].dwDeviceNum,
			               (LONG far *)&DriverHandle);
			}
         else
			{
            ErrCde = DRV_DeviceOpen(
			               SubDeviceList[gwSubDevice].dwDeviceNum,
			               (LONG far *)&DriverHandle);
			}
		
         if (ErrCde != SUCCESS)
			{
            strcpy(szErrMsg,"Device open error !");
            MessageBox(hDlg,(LPCSTR)szErrMsg,"Notice",MB_OK);
            return 0;
			}

         //Get device features
         ptDevFeatures.buffer = (LPDEVFEATURES)&DevFeatures;
         ptDevFeatures.size = sizeof(DEVFEATURES);
         ErrCde = DRV_DeviceGetFeatures(
            DriverHandle,
            (LPT_DeviceGetFeatures)&ptDevFeatures);
         if (ErrCde != SUCCESS)
         {
             DRV_GetErrorMessage(ErrCde,(LPSTR)szErrMsg);
             MessageBox(hDlg,(LPCSTR)szErrMsg,"Driver Message",MB_OK);
             DRV_DeviceClose((LONG far *)&DriverHandle);
         }
      
         //If the hardware does not have DI ports
         //Then the DI functions is unuasable
         if (ptDevFeatures.buffer->usMaxDIChl == 0)
         {
            EnableWindow(GetDlgItem(hDlg, IDC_READWORD), FALSE);
            EnableWindow(GetDlgItem(hDlg, IDC_READDWORD), FALSE);
         }

         //disable unused channels according to port num
         usPorts = (ptDevFeatures.buffer->usMaxDOChl)/8;
         usTemp = ptDevFeatures.buffer->usMaxDOChl % 8;
         if (usTemp != 0)
         {
            usPorts++;
            for (i = (usPorts - 1) * 8 + usTemp; i < usPorts * 8; i++)
            {
               EnableWindow(GetDlgItem(hDlg, (IDC_D0 + i)), FALSE);
            }
         }
         if (gwPort > (usPorts - 1))
         {
            for (i = 0; i < 32; i++)
            {
               EnableWindow(GetDlgItem(hDlg, (IDC_D0 + i)), FALSE);
            }
         }
         if (gwPort == (usPorts - 1))
         {
            for (i = 8; i < 32; i++)
            {
               EnableWindow(GetDlgItem(hDlg, (IDC_D0 + i)), FALSE);
            }
         }
         else if (gwPort == (usPorts - 2))
         {
            for (i = 16; i < 32; i++)
            {
               EnableWindow(GetDlgItem(hDlg, (IDC_D0 + i)), FALSE);
            }
         }
         else if (gwPort == (usPorts - 3))
         {
            for (i = 24; i < 32; i++)
            {
               EnableWindow(GetDlgItem(hDlg, (IDC_D0 + i)), FALSE);
            }
         }
                 
         return TRUE;
		}
   case WM_COMMAND :
		{
         switch (LOWORD(wParam))
			{
         case IDCANCEL :
				{
               EndDialog(hDlg, 0);
               if (DriverHandle != (LONG)NULL)
               {
                  ErrCde = DRV_DeviceClose(&DriverHandle);
               }
               if (ErrCde != SUCCESS)
			      {
                  strcpy(szErrMsg,"Device close error !");
                  MessageBox(hDlg,(LPCSTR)szErrMsg,"Notice",MB_OK);
			      }
               return TRUE;
				}//case IDCANCEL
         case IDC_WRITEWORDMASK:
            {
               EditLimitHexCharacter(hDlg, wParam);
               SendDlgItemMessage(hDlg, IDC_WRITEWORDMASK, EM_LIMITTEXT, 4, 0);
               break;
            }
         case IDC_WRITEDWORDMASK:
            {
               EditLimitHexCharacter(hDlg, wParam);
               SendDlgItemMessage(hDlg, IDC_WRITEDWORDMASK, EM_LIMITTEXT, 8, 0);
               break;
            }
         case IDC_WRITEWORD:
				{
               // get output byte value             
               glDoState = 0;
               for (i = 0; i < 16; i++)
               {
                  if ( IsDlgButtonChecked( hDlg, (IDC_D0 + i) ) > 0 )
                     glDoState = glDoState + (0x1<<i);
               }
               
					// get output mask.
					SendDlgItemMessage( hDlg,
						IDC_WRITEWORDMASK,
						WM_GETTEXT,
						16,
						( LPARAM )( ( LPSTR )szBuffer ) );
					gwWriteMask = ( USHORT )strtoul( 
                  szBuffer,
						&pchar,
						16 );
               // output word
				   ptDioWritePortWord.port = gwPort;
				   ptDioWritePortWord.mask = gwWriteMask;
				   ptDioWritePortWord.state = (USHORT)( glDoState & 0xffff);

               ErrCde = DRV_DioWritePortWord(
                  DriverHandle, 
					   (LPT_DioWritePortWord)&ptDioWritePortWord);
               if ( ErrCde != 0)
					{
                  DRV_GetErrorMessage(ErrCde,(LPSTR)szErrMsg);
                  MessageBox(hDlg,(LPCSTR)szErrMsg,"Driver Message",MB_OK);
                  return 0;
					}

               return TRUE;
				}//case IDC_WRITEWORD
         case IDC_WRITEDWORD:
				{
               // get output byte value
               glDoState = 0;
               for (i = 0; i < 32; i++)
               {
                  if (IsDlgButtonChecked(hDlg, (IDC_D0 + i)) > 0)
                     glDoState = glDoState | (0x1<<i);
               }
               
					// get output mask.
					SendDlgItemMessage( 
                  hDlg,
						IDC_WRITEDWORDMASK,
						WM_GETTEXT,
						16,
						( LPARAM )( ( LPSTR )szBuffer ) );
					glWriteMask = strtoul( szBuffer,
						&pchar,
						16 );
								
               // output DWord
					ptDioWritePortDword.port = gwPort;
					ptDioWritePortDword.mask = glWriteMask;
					ptDioWritePortDword.state = glDoState;
				
               ErrCde = DRV_DioWritePortDword(
                  DriverHandle,
						(LPT_DioWritePortDword)&ptDioWritePortDword);
					if ( ErrCde != 0 )
					{
                  DRV_GetErrorMessage(ErrCde,(LPSTR)szErrMsg);
                  MessageBox(hDlg,(LPCSTR)szErrMsg,"Driver Message",MB_OK);
                  return 0;
					}
				
               return TRUE;
				}//case IDC_WRITEDWORD
         case IDC_READWORD:
				{
               // read port word
					ptDioReadPortWord.port = gwPort;
					ptDioReadPortWord.ValidChannelMask = ( USHORT far * )&gwValidMask;
					ptDioReadPortWord.value = ( USHORT far * )&gwDiValue;
					ErrCde = DRV_DioReadPortWord(
                  DriverHandle, 
				   	(LPT_DioReadPortWord)&ptDioReadPortWord);
               if ( ErrCde != 0 )
					{
						DRV_GetErrorMessage(ErrCde,(LPSTR)szErrMsg);
						MessageBox(hDlg,(LPCSTR)szErrMsg,"Driver Message",MB_OK);
						return 0;
					}

               // display the value
               sprintf(szBuffer,"%X",gwDiValue);
               SendDlgItemMessage(
                  hDlg, 
                  IDC_WORDDATA, 
                  WM_SETTEXT, 
                  0,
                  (LPARAM)((LPSTR)szBuffer));
					// display the valid mask.
               sprintf(szBuffer,"%X", gwValidMask);
					SendDlgItemMessage( 
                  hDlg, 
                  IDC_READWORDMASK, 
                  WM_SETTEXT,
                  0,
                  (LPARAM)((LPSTR)szBuffer));

                  return TRUE;
				} //case IDC_READWORD

         case IDC_READDWORD:
				{
               // read port DWord
					ptDioReadPortDword.port = gwPort;
					ptDioReadPortDword.ValidChannelMask = ( ULONG far * )&glValidMask;
				   ptDioReadPortDword.value = ( ULONG far * )&glDiValue;
               ErrCde = DRV_DioReadPortDword( 
                  DriverHandle, 
				      ( LPT_DioReadPortDword )&ptDioReadPortDword );
               if( ErrCde != 0 )
					{
                  DRV_GetErrorMessage(ErrCde,(LPSTR)szErrMsg);
                  MessageBox(hDlg,(LPCSTR)szErrMsg,"Driver Message",MB_OK);
                  return 0;
					}
				
               // display the value
               sprintf(szBuffer,"%X",glDiValue);
               SendDlgItemMessage( hDlg,
						IDC_DWORDDATA,
						WM_SETTEXT,
						0,
					   ( LPARAM )( ( LPSTR )szBuffer ) );
					// display the valid mask.
               sprintf(szBuffer,"%X", glValidMask);
					SendDlgItemMessage( hDlg,
						IDC_READDWORDMASK,
						WM_SETTEXT,
						0,
						( LPARAM )( ( LPSTR )szBuffer ) );
				
               return TRUE;
				}//case IDC_READDWORD
			case IDC_GETDOWORD:
				{
				   //Get current DO word
					ptDioGetCurrentDOWord.port = gwPort;
					ptDioGetCurrentDOWord.ValidChannelMask = ( USHORT far * )&gwValidMask;
					ptDioGetCurrentDOWord.value = ( USHORT far * )&gwGetDOValue;
					ErrCde = DRV_DioGetCurrentDOWord( 
                  DriverHandle,
						( LPT_DioGetCurrentDOWord )&ptDioGetCurrentDOWord );
               if ( ErrCde != 0 )
					{
						DRV_GetErrorMessage( ErrCde, ( LPSTR )szErrMsg );
                  MessageBox( hDlg, ( LPCSTR )szErrMsg, "Driver Message", MB_OK );
                  return 0;
					}

					//Display current DO word value
               sprintf(szBuffer,"%X", gwGetDOValue);
					SendDlgItemMessage( hDlg,
						IDC_GETDOWORDVALUE,
						WM_SETTEXT,
						0,
						( LPARAM )( ( LPSTR )szBuffer ) );
					//Display current DO word valid mask
               sprintf(szBuffer,"%X", gwValidMask);
					SendDlgItemMessage( hDlg,
						IDC_GETDOWORDMASK,
						WM_SETTEXT,
						0,
						( LPARAM )( ( LPSTR )szBuffer ) );
					return TRUE;
				}//case IDC_GETDOWORD

			case IDC_GETDODWORD:
				{
					//Get current DO word
					ptDioGetCurrentDODword.port = gwPort;
					ptDioGetCurrentDODword.ValidChannelMask = ( ULONG far * )&glValidMask;
					ptDioGetCurrentDODword.value = ( ULONG far * )&glGetDOValue;
					ErrCde = DRV_DioGetCurrentDODword( 
                  DriverHandle,
						( LPT_DioGetCurrentDODword )&ptDioGetCurrentDODword );
               if ( ErrCde != 0 )
					{
						DRV_GetErrorMessage( ErrCde, ( LPSTR )szErrMsg );
                  MessageBox( hDlg, ( LPCSTR )szErrMsg, "Driver Message", MB_OK );
                  return 0;
					}
						
					//Display current DO word value
               sprintf(szBuffer,"%X", glGetDOValue);
					SendDlgItemMessage( hDlg,
						IDC_GETDODWORDVALUE,
						WM_SETTEXT,
						0,
						( LPARAM )( ( LPSTR )szBuffer ) );
					//Display current DO word valid mask
               sprintf(szBuffer,"%X", glValidMask);
					SendDlgItemMessage( hDlg,
						IDC_GETDODWORDMASK,
						WM_SETTEXT,
						0,
						( LPARAM )( ( LPSTR )szBuffer ) );
					return TRUE;
				}//case IDC_GETDODWORD
			} //switch (LOWORD(wParam))
         break;
		}//case WM_COMMAND
   }//switch (message)
   return FALSE ;
} // RunDlgProc

//*****************************************************************************
//    FUNCTION: MainWndProc(HWND, unsigned, WPARAM, LPARAM)
//
//    PURPOSE:  Processes messages
//
//    MESSAGES:
//
//        WM_CREATE     - create window
//        WM_COMMAND    - application menu (About dialog box)
//        WM_DESTROY    - destroy window
//-----------------------------------------------------------------------------
long FTYPE MainWndProc(
   HWND        hWnd,                          // window handle
   unsigned    message,                       // type of message
   WPARAM      wParam,                        // additional information
   LPARAM      lParam )                         // additional information
{
    static  HANDLE  hInstance ;

    switch (message)
    {
    case WM_CREATE:
       {
          hInstance = ((LPCREATESTRUCT) lParam)->hInstance ;
          lpfnConfigDlgProc = MakeProcInstance (ConfigDlgProc, hInstance) ;
          lpfnRunDlgProc = MakeProcInstance (RunDlgProc, hInstance) ;
          return 0 ;
       }
    case WM_COMMAND:     // message: from application menu
       {
          switch (LOWORD(wParam))
            {
            case IDM_SETTING :
                DialogBox (
                   hInstance, 
                   MAKEINTRESOURCE(IDD_SETTING),
                   hWnd, 
                   (DLGPROC)lpfnConfigDlgProc) ;
                return 0;

            case IDM_RUN :
                DialogBox (
                   hInstance, 
                   MAKEINTRESOURCE(IDD_RUN),
                   hWnd, 
                   (DLGPROC)lpfnRunDlgProc) ;
                return 0;
            }
          return 0;
       }            
    case WM_DESTROY:
       {
          PostQuitMessage(0);
          break;
       }      
    default:
       {
          return (DefWindowProc(hWnd, message, wParam, lParam));
       }       
   }
   return ((LONG)NULL);
}


//------------------------------------------------------------------
// Function:  Filter the key strokes that allow to display on edit 
//            control. 
//            This subroutine allows the 0-9, A-F characters.
// Paramater: hDlg, IN,  dialog box handle
//            wParam, IN, WPARAM along with windows message. 
// return:    none
//------------------------------------------------------------------
void EditLimitHexCharacter(HWND hDlg, WPARAM wParam)
{
	char  szOneLine[64];
	DWORD dwStart, dwStop;
	
	SendDlgItemMessage(hDlg, LOWORD(wParam), EM_GETSEL, (WPARAM)(&dwStart), (LPARAM)(&dwStop));
	
	*(USHORT*)szOneLine = sizeof(szOneLine);
	SendDlgItemMessage(hDlg, LOWORD(wParam), EM_GETLINE, 0, (LPARAM)szOneLine);
	
	// Get new added character index
	if( dwStart)
		dwStart--;
	else
		//No character on buffer
		return;
	
	//Check go through characters
	if( ('0' <= szOneLine[dwStart] && szOneLine[dwStart] <= '9')  ||
		('A' <= szOneLine[dwStart] && szOneLine[dwStart] <= 'F')  ||
		('a' <= szOneLine[dwStart] && szOneLine[dwStart] <= 'f'))
		return;
	
	//Delete this character.
	SendDlgItemMessage(hDlg, LOWORD(wParam), EM_SETSEL, (WPARAM)(dwStart), dwStop);
	szOneLine[0] = '\0';
	SendDlgItemMessage(hDlg, LOWORD(wParam), EM_REPLACESEL, FALSE, (LPARAM)szOneLine);
	
}//EditLimitHexCharacter
